@@ -8,7 +8,6 @@ describe 'heat::engine' do
       :heat_stack_user_role                => '<SERVICE DEFAULT>',
       :heat_metadata_server_url            => 'http://127.0.0.1:8000',
       :heat_waitcondition_server_url       => 'http://127.0.0.1:8000/v1/waitcondition',
-      :heat_watch_server_url               => 'http://128.0.0.1:8003',
       :engine_life_check_timeout           => '<SERVICE DEFAULT>',
       :trusts_delegated_roles              => '<SERVICE DEFAULT>',
       :deferred_auth_method                => '<SERVICE DEFAULT>',
@@ -20,6 +19,7 @@ describe 'heat::engine' do
       :environment_dir                     => '<SERVICE DEFAULT>',
       :template_dir                        => '<SERVICE DEFAULT>',
       :max_nested_stack_depth              => '<SERVICE DEFAULT>',
+      :plugin_dirs                         => '<SERVICE DEFAULT>',
     }
   end
 
@@ -38,7 +38,6 @@ describe 'heat::engine' do
         :heat_stack_user_role                => 'heat_stack_user',
         :heat_metadata_server_url            => 'http://127.0.0.1:8000',
         :heat_waitcondition_server_url       => 'http://127.0.0.1:8000/v1/waitcondition',
-        :heat_watch_server_url               => 'http://128.0.0.1:8003',
         :engine_life_check_timeout           => '2',
         :trusts_delegated_roles              => ['role1', 'role2'],
         :deferred_auth_method                => 'trusts',
@@ -81,7 +80,6 @@ describe 'heat::engine' do
       it { is_expected.to contain_heat_config('DEFAULT/heat_stack_user_role').with_value( expected_params[:heat_stack_user_role] ) }
       it { is_expected.to contain_heat_config('DEFAULT/heat_metadata_server_url').with_value( expected_params[:heat_metadata_server_url] ) }
       it { is_expected.to contain_heat_config('DEFAULT/heat_waitcondition_server_url').with_value( expected_params[:heat_waitcondition_server_url] ) }
-      it { is_expected.to contain_heat_config('DEFAULT/heat_watch_server_url').with_value( expected_params[:heat_watch_server_url] ) }
       it { is_expected.to contain_heat_config('DEFAULT/engine_life_check_timeout').with_value( expected_params[:engine_life_check_timeout] ) }
       it { is_expected.to contain_heat_config('DEFAULT/trusts_delegated_roles').with_value( expected_params[:trusts_delegated_roles] ) }
       it { is_expected.to contain_heat_config('DEFAULT/deferred_auth_method').with_value( expected_params[:deferred_auth_method] ) }
@@ -96,6 +94,7 @@ describe 'heat::engine' do
       it { is_expected.to contain_heat_config('DEFAULT/reauthentication_auth_method').with_value( expected_params[:reauthentication_auth_method] ) }
       it { is_expected.to contain_heat_config('DEFAULT/environment_dir').with_value( expected_params[:environment_dir] ) }
       it { is_expected.to contain_heat_config('DEFAULT/template_dir').with_value( expected_params[:template_dir] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/plugin_dirs').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with disabled service managing' do
@@ -114,6 +113,15 @@ describe 'heat::engine' do
         :tag        => 'heat-service',
       ) }
     end
+
+    context 'with plugin_dirs value set' do
+      before do
+        params.merge!({
+          :plugin_dirs => ['/usr/lib/heat', '/usr/local/lib/heat'] })
+      end
+      it { is_expected.to contain_heat_config('DEFAULT/plugin_dirs').with_value(['/usr/lib/heat,/usr/local/lib/heat']) }
+    end
+
     context 'with wrong auth_encryption_key parameter size' do
       before do
         params.merge!({
@@ -128,7 +136,7 @@ describe 'heat::engine' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts())
+        facts.merge!(OSDefaults.get_facts({:os_workers_heat_engine => 2}))
       end
 
       let :platform_params do
